@@ -8,15 +8,15 @@
 #ifndef QPIXMAPITEM_H
 #define QPIXMAPITEM_H
 
-#include <QQuickPaintedItem>
 #include <QPixmap>
+#include <QQuickPaintedItem>
 
 class QPixmapItem : public QQuickPaintedItem
 {
     Q_OBJECT
+    QML_ELEMENT
 
     Q_PROPERTY(QPixmap pixmap READ pixmap WRITE setPixmap NOTIFY pixmapChanged RESET resetPixmap)
-    Q_PROPERTY(bool smooth READ smooth WRITE setSmooth)
     Q_PROPERTY(int nativeWidth READ nativeWidth NOTIFY nativeWidthChanged)
     Q_PROPERTY(int nativeHeight READ nativeHeight NOTIFY nativeHeightChanged)
     Q_PROPERTY(int paintedWidth READ paintedWidth NOTIFY paintedWidthChanged)
@@ -31,20 +31,17 @@ public:
         PreserveAspectCrop, // the image is scaled uniformly to fill, cropping if necessary
         Tile, // the image is duplicated horizontally and vertically
         TileVertically, // the image is stretched horizontally and tiled vertically
-        TileHorizontally //the image is stretched vertically and tiled horizontally
+        TileHorizontally, // the image is stretched vertically and tiled horizontally
     };
     Q_ENUM(FillMode)
 
-    explicit QPixmapItem(QQuickItem *parent=nullptr);
+    explicit QPixmapItem(QQuickItem *parent = nullptr);
     ~QPixmapItem() override;
 
     void setPixmap(const QPixmap &pixmap);
     QPixmap pixmap() const;
     void resetPixmap();
 
-    void setSmooth(const bool smooth);
-    bool smooth() const;
-
     int nativeWidth() const;
     int nativeHeight() const;
 
@@ -68,17 +65,15 @@ Q_SIGNALS:
     void paintedHeightChanged();
 
 protected:
-    void geometryChanged(const QRectF & newGeometry, const QRectF & oldGeometry) override;
+    void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
 
 private:
     QPixmap m_pixmap;
-    bool m_smooth;
     FillMode m_fillMode;
     QRect m_paintedRect;
 
 private Q_SLOTS:
     void updatePaintedRect();
-
 };
 
 #endif
